@@ -23,7 +23,7 @@ class C2ProfileParameter:
         required: bool = True,
         verifier_regex: str = "",
         choices: [str] = None,
-        crypto_type: str = ""
+        crypto_type: bool = False,
     ):
         self.name = name
         self.description = description
